==> packaging-trinity-14.1.1.tar.xz: packaging-trinity-14.1.1/freebsd/dependencies/pinentry-tqt/files/patch-tqt_secqstring.h <==
--- tqt/secqstring.h.orig	2017-12-03 16:33:12 UTC
+++ tqt/secqstring.h
@@ -87,7 +87,7 @@ class SecTQCharRef;
 template <class T> class TQDeepCopy;
 #include <stdio.h>
 // internal
-struct Q_EXPORT SecTQStringData : public TQShared {
+struct TQ_EXPORT SecTQStringData : public TQShared {
     SecTQStringData() :
         TQShared(), unicode(0), len(0), maxl(0) { ref(); }
     SecTQStringData(TQChar *u, uint l, uint m) :
@@ -109,7 +109,7 @@ struct Q_EXPORT SecTQStringData : public TQShared {
 };
 
 
-class Q_EXPORT SecTQString
+class TQ_EXPORT SecTQString
 {
 public:
     SecTQString();                                  // make null string
@@ -191,7 +191,7 @@ class Q_EXPORT SecTQString (private)
     friend class TQDeepCopy<SecTQString>;
 };
 
-class Q_EXPORT SecTQCharRef {
+class TQ_EXPORT SecTQCharRef {
     friend class SecTQString;
     SecTQString& s;
     uint p;
@@ -249,7 +249,7 @@ class Q_EXPORT SecTQCharRef { (public)
 inline SecTQCharRef SecTQString::at( uint i ) { return SecTQCharRef(this,i); }
 inline SecTQCharRef SecTQString::operator[]( int i ) { return at((uint)i); }
 
-class Q_EXPORT SecTQConstString : private SecTQString {
+class TQ_EXPORT SecTQConstString : private SecTQString {
 public:
     SecTQConstString( const TQChar* unicode, uint length );
     ~SecTQConstString();
@@ -297,7 +297,7 @@ inline bool SecTQString::isEmpty() const
   SecTQString non-member operators
  *****************************************************************************/
 
-Q_EXPORT inline const SecTQString operator+( const SecTQString &s1, const SecTQString &s2 )
+TQ_EXPORT inline const SecTQString operator+( const SecTQString &s1, const SecTQString &s2 )
 {
     SecTQString tmp( s1 );
     tmp += s2;

==> packaging-trinity-14.1.3.tar.xz: packaging-trinity-14.1.3/freebsd/dependencies/pinentry-tqt/files/patch-tqt_secqstring.h <==
--- tqt/secqstring.h.orig
+++ tqt/secqstring.h
@@ -87,7 +87,7 @@ class SecTQCharRef;
 template <class T> class TQDeepCopy;
 #include <stdio.h>
 // internal
-struct Q_EXPORT SecTQStringData : public TQShared {
+struct TQ_EXPORT SecTQStringData : public TQShared {
     SecTQStringData() :
         TQShared(), unicode(0), len(0), maxl(0) { ref(); }
     SecTQStringData(TQChar *u, uint l, uint m) :
@@ -109,7 +109,7 @@ struct Q_EXPORT SecTQStringData : public TQShared {
 };
 
 
-class Q_EXPORT SecTQString
+class TQ_EXPORT SecTQString
 {
 public:
     SecTQString();                                  // make null string
@@ -125,7 +125,7 @@
 
     SecTQString    &operator=( const SecTQString & );   // impl-shared copy
 
-    QT_STATIC_CONST SecTQString null;
+    static const SecTQString null;
 
     bool        isNull()        const;
     bool        isEmpty()       const;
@@ -191,7 +191,7 @@ class Q_EXPORT SecTQString (private)
     friend class TQDeepCopy<SecTQString>;
 };
 
-class Q_EXPORT SecTQCharRef {
+class TQ_EXPORT SecTQCharRef {
     friend class SecTQString;
     SecTQString& s;
     uint p;
@@ -249,7 +249,7 @@ class Q_EXPORT SecTQCharRef { (public)
 inline SecTQCharRef SecTQString::at( uint i ) { return SecTQCharRef(this,i); }
 inline SecTQCharRef SecTQString::operator[]( int i ) { return at((uint)i); }
 
-class Q_EXPORT SecTQConstString : private SecTQString {
+class TQ_EXPORT SecTQConstString : private SecTQString {
 public:
     SecTQConstString( const TQChar* unicode, uint length );
     ~SecTQConstString();
@@ -297,7 +297,7 @@ inline bool SecTQString::isEmpty() const
   SecTQString non-member operators
  *****************************************************************************/
 
-Q_EXPORT inline const SecTQString operator+( const SecTQString &s1, const SecTQString &s2 )
+TQ_EXPORT inline const SecTQString operator+( const SecTQString &s1, const SecTQString &s2 )
 {
     SecTQString tmp( s1 );
     tmp += s2;
